{% load coop_navigation %}
{% with has_children=node.has_children is_active=node.is_active_node %}
{% spaceless %}
<li class="{% if has_children %}dropdown{% endif %} {% if is_active %}active{% endif %}">
  <a{% if node.get_absolute_url %} href="{{ node.get_absolute_url }}"{% endif %}>
    <img src="{{MEDIA_URL}}{{ node.label|slugify }}.png" alt="" />
	  {{ node.label }} - {{ user.username }}
  </a>
  {% if has_children %}
  <ul class="dropdown-menu">
    {% for child in node.get_children_navigation %}
        {{ child|render_template_node }}
    {% endfor %}
  </ul>
  {% endif %}
</li>
{% endspaceless %}
{% endwith %}