{% load coop_edition coop_utils %}
{% if COOP_CMS_JQUERY_VERSION %}
    <script type="text/javascript" charset="utf-8" src="{% versioned_static_file COOP_CMS_JQUERY_VERSION %}"></script>
{% else %}
    {% if debug %}
    <script type="text/javascript" charset="utf-8" src="{% versioned_static_file 'js/jquery-1.11.3.js' %}"></script>
    {% else %}
    <script type="text/javascript" charset="utf-8" src="{% versioned_static_file 'js/jquery-1.11.3.min.js' %}"></script>
    {% endif %}
{% endif %}
{% if_cms_edition %}
    <!--- <script type="text/javascript" charset="utf-8" src="{{ STATIC_URL }}js/jquery-migrate-1.2.1.min.js"></script>--->
    {% cms_form_media %}
{% else %}
    {% if request.user.is_authenticated %}
        <script type="text/javascript" charset="utf-8" src="{% versioned_static_file 'js/jquery.colorbox-min.js' %}"></script>
        <script type="text/javascript" charset="utf-8" src="{% versioned_static_file 'js/jquery.form.js' %}"></script>
        <script type="text/javascript" src="{% versioned_static_file 'js/colorbox.coop.js' %}"></script>
        <link rel="stylesheet" href="{% versioned_static_file 'css/colorbox.css' %}" type="text/css" />
    {% endif %}
{% endif %}