{% extends "colorbox/popup_form_base.html" %}
{% load i18n %}
{% block title %}{% trans "Switch language" %}{% endblock %}
{% block form_url %}{% url "coop_cms_switch_language_popup" %}{% endblock %}
