{% extends "registration/base.html" %}{% load i18n %}
{% block registration_content %}
<h2>{% trans "Password reset" %}</h2>
<form class="loginform" action="" method="post" class="registration-form">{% csrf_token %}
    <table>
        {{form.as_table}}
        <tr>
        <td>&nbsp;</td>
        <td><input type="submit" value="{% trans "Reset" %}" /></td>
        <tr>    
    </table>
</form>
{% endblock %}