{% extends "registration/base.html" %}{% load i18n %}
{% block registration_content %}
<h2>{% trans "The password has been changed" %}</h2>
<p>
    {% trans "Go back to the" %} <a href="{% url "homepage" %}">{% trans "Homepage" %}</a>
</p>
{% endblock %}
    
