{% extends "coop_cms/navtree_content/default.html" %}
{% load i18n %}
    
    {% block navtree_content_extracommand%}
    <li><a href="{{node.content_object.get_edit_url}}">{% trans "Edit on site"%}</a></li>
    {% endblock %}
